package ruledemo;

import org.junit.*;
import org.junit.Test;

public class RuleContainerTestSuite
{
	private RuleContainer _ruleContainer;
	
	@Before
	public void PerTestSetup()
	{
		_ruleContainer = new RuleContainer();
	}
	
	@Test
	public void ReportsSize()
	{
		Assert.assertEquals("Haven't added anything", 0, _ruleContainer.getSize());
		
		Rule rule = new Rule("TestRule","TestSQL", Rule.Priority.Low);
		_ruleContainer.addRule(rule);
		Assert.assertEquals("Report the size of the RuleContainer", 1, _ruleContainer.getSize());
	}
	
	@Test
	public void AddRule()
	{
		Rule rule = new Rule("TestRule","TestSQL", Rule.Priority.Low);
		_ruleContainer.addRule(rule);
		Assert.assertEquals("Adding rule should increase size by 1", 1, _ruleContainer.getSize());
	}
	
	@Test
	public void GetRule()
	{
		String testID = "TestRule";
		Rule rule = new Rule(testID, "TestSQL", Rule.Priority.Low);

		_ruleContainer.addRule(rule);
		Assert.assertEquals("Can get the same Rule back", rule, _ruleContainer.getRule(testID));
	}
	
	@Test
	public void DuplicateRule()
	{
		String testID = "TestRule";
		Rule rule = new Rule(testID,"TestSQL", Rule.Priority.High);
		Rule duplicateRule = new Rule(testID,"TestSQL", Rule.Priority.Low);
		_ruleContainer.addRule(rule);
		_ruleContainer.addRule(duplicateRule);
		
		Assert.assertEquals("Duplicate does not increase size",1,_ruleContainer.getSize());
		Assert.assertSame("New Rule replaced old",duplicateRule,_ruleContainer.getRule(testID));
		Assert.assertEquals("Priority set to High on replacement", Rule.Priority.High, _ruleContainer.getRule(testID).getPriority());
	}
	
	@Test(expected=IllegalArgumentException.class)
	public void EmptyID()
	{
		Rule rule = new Rule("","TestSQL", Rule.Priority.High);
		_ruleContainer.addRule(rule);
	}
	
}
